@@ -69,9 +69,9 @@ impl Tokenizer {
     #[inline(always)]
     fn tokenize_slice<'a>(&self, slice: &'a str) -> Vec<Cow<'a, str>> {
         let iter = slice
-            .split_ascii_whitespace()
+            .split_whitespace()
             .map(|term_slice| {
-                let ascii_folded = ascii_folding_filter::to_ascii(&term_slice);
+                let ascii_folded = ascii_folding_filter::to_ascii(term_slice);
                 term_filter(ascii_folded)
             })
             .filter(|term| {
@@ -113,7 +113,7 @@ impl TokenizerTrait for Tokenizer {
     fn get_best_corrected_term(
         &self,
         _term: &str,
-        _dictionary: &FxHashMap<Rc<SmartString>, Rc<TermInfo>>,
+        _dictionary: &FxHashMap<Rc<SmartString>, TermInfo>,
     ) -> Option<String> {
         None
     }
@@ -122,7 +122,7 @@ impl TokenizerTrait for Tokenizer {
         &self,
         _number_of_expanded_terms: usize,
         _term: &str,
-        _dictionary: &FxHashMap<Rc<SmartString>, Rc<TermInfo>>,
+        _dictionary: &FxHashMap<Rc<SmartString>, TermInfo>,
     ) -> FxHashMap<String, f32> {
         FxHashMap::default()
     }
